@@ -22,7 +22,7 @@ from ..utils._check_arrays import check_X_y
 class PolynomialNarmax(
     GenerateRegressors, HouseHolder, InformationMatrix, ResiduesAnalysis, Estimators
 ):
-    """ Polynomial NARXMAX model
+    """Polynomial NARXMAX model
 
     Parameters
     ----------
@@ -126,14 +126,14 @@ class PolynomialNarmax(
         n_terms=None,
         n_inputs=1,
         n_info_values=10,
-        estimator="least_squares",
+        estimator="recursive_least_squares",
         extended_least_squares=True,
         aux_lag=1,
         lam=0.98,
         delta=0.01,
         offset_covariance=0.2,
         mu=0.01,
-        eps=np.finfo(np.float).eps,
+        eps=np.finfo(np.float64).eps,
         gama=0.2,
         weight=0.02,
     ):
@@ -159,7 +159,7 @@ class PolynomialNarmax(
         self._lam = lam
         self._delta = delta
         self._gama = gama
-        self._weight = weight  # <0  e <1
+        self._weight = weight  # 0 < weight <1
         self._validate_params()
 
     def _validate_params(self):
@@ -244,9 +244,9 @@ class PolynomialNarmax(
             e Novos Resultados
 
         """
-        squared_y = y[self.max_lag:].T @ y[self.max_lag:]
+        squared_y = y[self.max_lag :].T @ y[self.max_lag :]
         tmp_psi = np.array(psi)
-        y = np.array([y[self.max_lag:, 0]]).T
+        y = np.array([y[self.max_lag :, 0]]).T
         tmp_y = np.copy(y)
         [n, dimension] = tmp_psi.shape
         piv = np.arange(dimension)
@@ -257,8 +257,7 @@ class PolynomialNarmax(
             for j in np.arange(i, dimension):
                 num = np.array(tmp_psi[i:n, j].T @ tmp_y[i:n])
                 num = np.power(num, 2)
-                den = np.array(
-                    (tmp_psi[i:n, j].T @ tmp_psi[i:n, j]) * squared_y)
+                den = np.array((tmp_psi[i:n, j].T @ tmp_psi[i:n, j]) * squared_y)
                 tmp_err[j] = num / den
 
             if i == process_term_number:
@@ -333,8 +332,7 @@ class PolynomialNarmax(
             self.info_values = self.information_criterion(X, y)
 
         if self.n_terms is None and self._order_selection is True:
-            model_length = np.where(
-                self.info_values == np.amin(self.info_values))
+            model_length = np.where(self.info_values == np.amin(self.info_values))
             model_length = int(model_length[0] + 1)
             self.n_terms = model_length
         elif self.n_terms is None and self._order_selection is not True:
@@ -413,18 +411,15 @@ class PolynomialNarmax(
                 ee, y, elag, 1, 2
             )
 
-            psi_extended = psi_extended[:, [
-                2, 3, 7, 8, 11, 12, 13, 14, 15, 16, 17]]
+            psi_extended = psi_extended[:, [2, 3, 7, 8, 11, 12, 13, 14, 15, 16, 17]]
 
             psi_e = np.concatenate([psi, psi_extended], axis=1)
-            unbiased_theta = getattr(
-                parameter_estimation, self.estimator)(psi_e, y)
-            e = y[aux_lag:, 0].reshape(-1, 1) - \
-                psi_e @ unbiased_theta.reshape(-1, 1)
+            unbiased_theta = getattr(parameter_estimation, self.estimator)(psi_e, y)
+            e = y[aux_lag:, 0].reshape(-1, 1) - psi_e @ unbiased_theta.reshape(-1, 1)
 
-        return unbiased_theta[0: len(self.final_model), 0].reshape(-1, 1)
+        return unbiased_theta[0 : len(self.final_model), 0].reshape(-1, 1)
 
-    def predict(self, X, y):
+    def predict(self, X, y, steps_ahead=None):
         """Return the predicted values given an input.
 
         The predict function allows a friendly usage by the user.
@@ -440,6 +435,8 @@ class PolynomialNarmax(
             The input data to be used in the prediction process.
         y : ndarray of floats
             The output data to be used in the prediction process.
+        steps_ahead = int (default = None)
+            The forecast horizon.
 
         Returns
         -------
@@ -447,8 +444,13 @@ class PolynomialNarmax(
             The predicted values of the model.
 
         """
-        yhat = self._model_prediction(self.final_model, X, y, self.theta)
-        return yhat
+        if steps_ahead is None:
+            return self._model_prediction(X, y)
+        elif steps_ahead == 1:
+            return self._one_step_ahead_prediction(X, y)
+        else:
+            self._check_positive_int(steps_ahead, "steps_ahead")
+            return self._n_step_ahead_prediction(X, y, steps_ahead=steps_ahead)
 
     def _code2exponents(self, code):
         """
@@ -484,20 +486,85 @@ class PolynomialNarmax(
 
             return exponents
 
-    def _model_prediction(self, model_elements, X, y_initial, theta):
+    def _check_positive_int(self, value, name):
+        if not isinstance(value, int) or value < 1:
+            raise ValueError(f"{name} must be integer and > zero. Got {value}")
+
+    def _one_step_ahead_prediction(self, X, y):
+        """Perform the 1-step-ahead prediction of a model.
+
+        Parameters
+        ----------
+        y : array-like of shape = max_lag
+            Initial conditions values of the model
+            to start recursive process.
+        X : ndarray of floats of shape = n_samples
+            Vector with entrace values to be used in model simulation.
+
+        Returns
+        -------
+        yhat : ndarray of floats
+               The 1-step-ahead predicted values of the model.
+
+        """
+        X_base = InformationMatrix().build_information_matrix(
+            X, y, self.xlag, self.ylag, self.non_degree
+        )
+        piv_final_model = self.pivv[: len(self.final_model)]
+        X_base = X_base[:, piv_final_model]
+        yhat = np.dot(X_base, self.theta.flatten())
+        yhat = np.concatenate([y[: self.max_lag].flatten(), yhat])
+        return yhat.reshape(-1, 1)
+
+    def _n_step_ahead_prediction(self, X, y, steps_ahead):
+        """Perform the n-steps-ahead prediction of a model.
+
+        Parameters
+        ----------
+        y : array-like of shape = max_lag
+            Initial conditions values of the model
+            to start recursive process.
+        X : ndarray of floats of shape = n_samples
+            Vector with entrace values to be used in model simulation.
+
+        Returns
+        -------
+        yhat : ndarray of floats
+               The n-steps-ahead predicted values of the model.
+
+        """
+        if len(y) < self.max_lag:
+            raise Exception("Insufficient initial conditions elements!")
+
+        yhat = np.zeros(X.shape[0], dtype=float)
+        yhat.fill(np.nan)
+        yhat[: self.max_lag] = y[: self.max_lag, 0]
+        i = self.max_lag
+        X = X.reshape(-1, self._n_inputs)
+        while i < len(y):
+            k = int(i - self.max_lag)
+            if i + steps_ahead > len(y):
+                steps_ahead = len(y) - i  # predicts the remaining values
+
+            yhat[i : i + steps_ahead] = self._model_prediction(
+                X[k : i + steps_ahead], y[k : i + steps_ahead]
+            )[-steps_ahead:].ravel()
+
+            i += steps_ahead
+
+        yhat = yhat.ravel()
+        return yhat.reshape(-1, 1)
+
+    def _model_prediction(self, X, y_initial):
         """Perform the infinity steps-ahead simulation of a model.
 
         Parameters
         ----------
-        model_elements : ndarray of ints
-            Matrix with regressor codes.
         y_initial : array-like of shape = max_lag
             Number of initial conditions values of output mensured
             to start recursive process.
         X : ndarray of floats of shape = n_samples
             Vector with entrace values to be used in model simulation.
-        theta : array-like of shape = number_of_model_elements
-            Paramters estimated via Least Squares method.
 
         Returns
         -------
@@ -513,8 +580,7 @@ class PolynomialNarmax(
         y_output.fill(np.nan)
         y_output[: self.max_lag] = y_initial[: self.max_lag, 0]
 
-        model_exponents = [self._code2exponents(
-            model) for model in model_elements]
+        model_exponents = [self._code2exponents(model) for model in self.final_model]
         raw_regressor = np.zeros(len(model_exponents[0]), dtype=float)
 
         for i in range(self.max_lag, X.shape[0]):
@@ -533,7 +599,7 @@ class PolynomialNarmax(
                     np.power(raw_regressor, model_exponents[j])
                 )
 
-            y_output[i] = np.dot(regressor_value, theta.flatten())
+            y_output[i] = np.dot(regressor_value, self.theta.flatten())
         return y_output.reshape(-1, 1)
 
     def information_criterion(self, X, y):
@@ -601,19 +667,17 @@ class PolynomialNarmax(
 
         for i in range(0, self.n_info_values):
             n_theta = i + 1
-            regressor_matrix = self.error_reduction_ratio(X_base, y, n_theta)[
-                3]
+            regressor_matrix = self.error_reduction_ratio(X_base, y, n_theta)[3]
 
             tmp_theta = getattr(parameter_estimation, self.estimator)(
                 regressor_matrix, y
             )
 
             tmp_yhat = regressor_matrix @ tmp_theta
-            tmp_residual = y[self.max_lag:] - tmp_yhat
+            tmp_residual = y[self.max_lag :] - tmp_yhat
             e_var = np.var(tmp_residual, ddof=1)
 
-            output_vector[i] = self.compute_info_value(
-                n_theta, n_samples, e_var)
+            output_vector[i] = self.compute_info_value(n_theta, n_samples, e_var)
 
             # output_vector[i] = e_factor + model_factor
 
@@ -683,8 +747,7 @@ class PolynomialNarmax(
                         translated_exponent = ""
                     else:
                         delay_string = str(
-                            int(regressor_key -
-                                np.floor(regressor_key / 1000) * 1000)
+                            int(regressor_key - np.floor(regressor_key / 1000) * 1000)
                         )
                         if int(regressor_key / 1000) < 2:
                             translated_key = "y(k-" + delay_string + ")"
@@ -702,8 +765,7 @@ class PolynomialNarmax(
                             translated_exponent = "^" + str(
                                 regressor_dic[regressor_key]
                             )
-                    regressor_string.append(
-                        translated_key + translated_exponent)
+                    regressor_string.append(translated_key + translated_exponent)
                 tmp_regressor = "".join(regressor_string)
 
             current_parameter = theta_output_format.format(self.theta[i, 0])
