@@ -82,14 +82,14 @@ def test_default_values():
         "n_terms": None,
         "n_inputs": 1,
         "n_info_values": 10,
-        "estimator": "least_squares",
+        "estimator": "recursive_least_squares",
         "extended_least_squares": True,
         "aux_lag": 1,
         "lam": 0.98,
         "delta": 0.01,
         "offset_covariance": 0.2,
         "mu": 0.01,
-        "eps": np.finfo(np.float).eps,
+        "eps": np.finfo(np.float64).eps,
         "gama": 0.2,
         "weight": 0.02,
     }
